@@ -1,5 +1,28 @@
 use criterion::{black_box, criterion_group, criterion_main, Criterion};
 
+// ref.) https://en.wikipedia.org/wiki/Memory_ordering
+fn memory_barrier(_arg: &Vec<&str>) {
+    #[cfg(target_feature = "sse2")]
+    {
+        #[cfg(target_arch = "x86")]
+        use std::arch::x86 as mmx;
+        #[cfg(target_arch = "x86_64")]
+        use std::arch::x86_64 as mmx;
+
+        unsafe { mmx::_mm_mfence() };
+    }
+    /*
+    #[cfg(target_arch = "arm")]
+    {
+        unsafe { core::arch::arm::__dmb(_arg) };
+    }
+    #[cfg(target_arch = "aarch64")]
+    {
+        unsafe { core::arch::aarch64::__dmb(_arg) };
+    }
+    */
+}
+
 #[inline(never)]
 fn process_std_memmem(texts: &[&str], pattern: &str) -> usize {
     let pat_len = pattern.len();
@@ -125,30 +148,36 @@ fn criterion_benchmark(c: &mut Criterion) {
     assert_eq!(n, match_cnt);
     let n = process_memchr_memmem(black_box(&vv), black_box(&pat_string));
     assert_eq!(n, match_cnt);
+    memory_barrier(&vv);
     //
     c.bench_function("std_memmem", |b| {
         b.iter(|| {
             let _r = process_std_memmem(black_box(&vv), black_box(&pat_string));
+            memory_barrier(&vv);
         })
     });
     c.bench_function("memx_memmem", |b| {
         b.iter(|| {
             let _r = process_memx_memmem(black_box(&vv), black_box(&pat_string));
+            memory_barrier(&vv);
         })
     });
     c.bench_function("memx_memmem_basic", |b| {
         b.iter(|| {
             let _r = process_memx_memmem_basic(black_box(&vv), black_box(&pat_string));
+            memory_barrier(&vv);
         })
     });
     c.bench_function("memx_memmem_libc", |b| {
         b.iter(|| {
             let _r = process_memx_memmem_libc(black_box(&vv), black_box(&pat_string));
+            memory_barrier(&vv);
         })
     });
     c.bench_function("memchr_memmem", |b| {
         b.iter(|| {
             let _r = process_memchr_memmem(black_box(&vv), black_box(&pat_string));
+            memory_barrier(&vv);
         })
     });
 }
