@@ -34,6 +34,14 @@ mod x86_mem;
 ))]
 pub(crate) use x86_mem::_memmem_impl;
 
+mod x86_rchr;
+
+#[cfg(all(
+    any(target_arch = "x86_64", target_arch = "x86"),
+    any(target_feature = "sse2", target_feature = "avx")
+))]
+pub(crate) use x86_rchr::_memrchr_impl;
+
 mod x86_set;
 
 #[cfg(all(
